==> flutter_widgetz-4.9.4.tar.gz: example/lib/pages/dropdown_field_page.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_widgetz/flutter_widgetz.dart';

class DropdownFieldPage extends StatelessWidget {
  const DropdownFieldPage({super.key});

  @override
  Widget build(BuildContext context) {
    return CustomSingleChildScrollView(
      padding: const EdgeInsets.all(16.0),
      child: CustomOrientationBuilder(
        landscapeBuilder: (_) {
          return const SpacedRow(
            children: <Widget>[
              DropdownField<String>(
                labelText: 'Dropdown One',
                items: <String>['1', '2', '3'],
                onChanged: print,
                prefixIcon: Icons.gif_box,
              ),
              CustomTextField(
                labelText: 'Text Field (for reference)',
                prefixIcon: Icons.abc,
              ),
            ],
          );
        },
        portraitBuilder: (_) {
          return SpacedColumn(
            children: <Widget>[
              const CustomTextField(
                labelText: 'Text Field (for reference)',
                prefixIcon: Icons.gif_box,
              ),
              const DropdownField<String>(
                labelText: 'Dropdown One',
                items: <String>['1', '2', '3'],
                onChanged: print,
              ),
              const DropdownField<BoxFit>(
                labelText: 'Dropdown Two',
                items: <BoxFit>[
                  BoxFit.contain,
                  BoxFit.cover,
                  BoxFit.fill,
                ],
                onChanged: print,
                prefixIcon: Icons.gif_outlined,
              ),
              DropdownField<BoxFit>(
                labelText: 'Dropdown Three (Formatted)',
                items: const <BoxFit>[
                  BoxFit.contain,
                  BoxFit.cover,
                  BoxFit.fill,
                ],
                onChanged: print,
                displayStringForItem: (BoxFit v) => v.name,
                prefixIcon: Icons.gif_box,
              ),
              DropdownField<BoxFit>(
                labelText: 'Dropdown Four (Initial Value)',
                items: const <BoxFit>[
                  BoxFit.contain,
                  BoxFit.cover,
                  BoxFit.fill,
                ],
                onChanged: print,
                displayStringForItem: (BoxFit v) => v.name,
                prefixIcon: Icons.select_all,
                value: BoxFit.fill,
              ),
            ],
          );
        },
      ),
    );
  }
}

==> flutter_widgetz-8.0.2.tar.gz: example/lib/pages/dropdown_field_page.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_widgetz/flutter_widgetz.dart';

class DropdownFieldPage extends StatelessWidget {
  const DropdownFieldPage({super.key});

  @override
  Widget build(BuildContext context) {
    return CustomSingleChildScrollView(
      padding: const EdgeInsets.all(16.0),
      child: CustomOrientationBuilder(
        landscapeBuilder: (_) {
          return const SpacedRow(
            children: <Widget>[
              DropdownField<String>(
                labelText: 'Dropdown One',
                items: <String>['1', '2', '3'],
                onChanged: print,
                prefixIcon: Icon(Icons.gif_box),
              ),
              CustomTextField(
                labelText: 'Text Field (for reference)',
                prefixIcon: Icon(Icons.abc),
              ),
            ],
          );
        },
        portraitBuilder: (_) {
          return SpacedColumn(
            children: <Widget>[
              const CustomTextField(
                labelText: 'Text Field (for reference)',
                prefixIcon: Icon(Icons.gif_box),
              ),
              const DropdownField<String>(
                labelText: 'Dropdown One',
                items: <String>['1', '2', '3'],
                onChanged: print,
              ),
              const DropdownField<BoxFit>(
                labelText: 'Dropdown Two',
                items: <BoxFit>[
                  BoxFit.contain,
                  BoxFit.cover,
                  BoxFit.fill,
                ],
                onChanged: print,
                prefixIcon: Icon(Icons.gif_outlined),
              ),
              DropdownField<BoxFit>(
                labelText: 'Dropdown Three (Formatted)',
                items: const <BoxFit>[
                  BoxFit.contain,
                  BoxFit.cover,
                  BoxFit.fill,
                ],
                onChanged: print,
                displayStringForItem: (BoxFit v) => v.name,
                prefixIcon: const Icon(Icons.gif_box),
              ),
              DropdownField<BoxFit>(
                labelText: 'Dropdown Four (Initial Value)',
                items: const <BoxFit>[
                  BoxFit.contain,
                  BoxFit.cover,
                  BoxFit.fill,
                ],
                onChanged: print,
                displayStringForItem: (BoxFit v) => v.name,
                prefixIcon: const Icon(Icons.select_all),
                value: BoxFit.fill,
              ),
            ],
          );
        },
      ),
    );
  }
}
